@@ -3,12 +3,12 @@
  * nodeTidscan.c
  *	  Routines to support direct tid scans of relations
  *
- * Portions Copyright (c) 1996-2001, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2002, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/executor/nodeTidscan.c,v 1.22 2002/02/11 20:10:50 tgl Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/executor/nodeTidscan.c,v 1.26 2002/09/04 20:31:18 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -109,8 +109,8 @@ TidNext(TidScan *node)
 			return slot;		/* return empty slot */
 
 		/*
-		 * XXX shouldn't we check here to make sure tuple matches TID list?
-		 * In runtime-key case this is not certain, is it?
+		 * XXX shouldn't we check here to make sure tuple matches TID
+		 * list? In runtime-key case this is not certain, is it?
 		 */
 
 		ExecStoreTuple(estate->es_evTuple[node->scan.scanrelid - 1],
@@ -150,11 +150,8 @@ TidNext(TidScan *node)
 	{
 		bool		slot_is_valid = false;
 
-		tuple->t_datamcxt = NULL;
-		tuple->t_data = NULL;
 		tuple->t_self = tidList[tidstate->tss_TidPtr];
-		heap_fetch(heapRelation, snapshot, tuple, &buffer, NULL);
-		if (tuple->t_data != NULL)
+		if (heap_fetch(heapRelation, snapshot, tuple, &buffer, false, NULL))
 		{
 			bool		prev_matches = false;
 			int			prev_tid;
@@ -198,8 +195,6 @@ TidNext(TidScan *node)
 			else
 				ExecClearTuple(slot);
 		}
-		else if (BufferIsValid(buffer))
-			ReleaseBuffer(buffer);
 		tidNumber++;
 		if (bBackward)
 			tidstate->tss_TidPtr--;
@@ -300,15 +295,14 @@ ExecEndTidScan(TidScan *node)
 	CommonScanState *scanstate;
 	TidScanState *tidstate;
 
+	/*
+	 * extract information from the node
+	 */
 	scanstate = node->scan.scanstate;
 	tidstate = node->tidstate;
 	if (tidstate && tidstate->tss_TidList)
 		pfree(tidstate->tss_TidList);
 
-	/*
-	 * extract information from the node
-	 */
-
 	/*
 	 * Free the projection info and the scan attribute info
 	 *
@@ -320,9 +314,13 @@ ExecEndTidScan(TidScan *node)
 	ExecFreeExprContext(&scanstate->cstate);
 
 	/*
-	 * close the heap and tid relations
+	 * close the heap relation.
+	 *
+	 * Currently, we do not release the AccessShareLock acquired by
+	 * ExecInitTidScan.  This lock should be held till end of transaction.
+	 * (There is a faction that considers this too much locking, however.)
 	 */
-	ExecCloseR((Plan *) node);
+	heap_close(scanstate->css_currentRelation, NoLock);
 
 	/*
 	 * clear out tuple table slots
@@ -460,14 +458,17 @@ ExecInitTidScan(TidScan *node, EState *estate, Plan *parent)
 
 	/*
 	 * open the base relation
+	 *
+	 * We acquire AccessShareLock for the duration of the scan.
 	 */
 	relid = node->scan.scanrelid;
 	rtentry = rt_fetch(relid, rangeTable);
 	reloid = rtentry->relid;
 
 	currentRelation = heap_open(reloid, AccessShareLock);
+
 	scanstate->css_currentRelation = currentRelation;
-	scanstate->css_currentScanDesc = 0;
+	scanstate->css_currentScanDesc = NULL;		/* no heap scan here */
 
 	/*
 	 * get the scan type from the relation descriptor.
