@@ -4,10 +4,10 @@
  *	  POSTGRES shared cache invalidation segment definitions.
  *
  *
- * Portions Copyright (c) 1996-2001, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2002, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
- * $Id: sinvaladt.h,v 1.30 2001/11/05 17:46:35 momjian Exp $
+ * $Id: sinvaladt.h,v 1.33 2002/08/29 21:02:12 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -71,7 +71,7 @@ typedef struct ProcState
 	/* nextMsgNum is -1 in an inactive ProcState array entry. */
 	int			nextMsgNum;		/* next message number to read, or -1 */
 	bool		resetState;		/* true, if backend has to reset its state */
-	SHMEM_OFFSET procStruct;	/* location of backend's PROC struct */
+	SHMEM_OFFSET procStruct;	/* location of backend's PGPROC struct */
 } ProcState;
 
 /* Shared cache invalidation memory segment */
@@ -85,6 +85,7 @@ typedef struct SISeg
 	int			lastBackend;	/* index of last active procState entry,
 								 * +1 */
 	int			maxBackends;	/* size of procState array */
+	int			freeBackends;	/* number of empty procState slots */
 
 	/*
 	 * Circular buffer holding shared-inval messages
