@@ -1,11 +1,9 @@
 --
--- errors.source
+-- ERRORS
 --
--- $Header: /usr/local/cvsroot/pgsql/src/test/regress/sql/errors.sql,v 1.2 1997/05/22 00:17:24 scrappy Exp $
- 
 
 -- bad in postquel, but ok in postsql
-select 1
+select 1;
 
 
 --
@@ -22,11 +20,13 @@ select 1
 -- RETRIEVE
  
 -- missing relation name 
-select
+select;
 
 -- no such relation 
 select * from nonesuch;
 
+-- missing target list
+select from pg_database;
 -- bad name in target list
 select nonesuch from pg_database;
 -- bad attribute name on lhs of operator
@@ -36,12 +36,12 @@ select * from pg_database where nonesuch = pg_database.datname;
 select * from pg_database where pg_database.datname = nonesuch;
 
 
--- bad select distinct on  syntax,  distinct attribute missing
-select distinct on foobar from pg_database;
+-- bad select distinct on syntax, distinct attribute missing
+select distinct on (foobar) from pg_database;
 
 
 -- bad select distinct on syntax, distinct attribute not in target list
-select distinct on foobar * from pg_database;
+select distinct on (foobar) * from pg_database;
 
 
 --
@@ -79,9 +79,6 @@ alter table nonesuch rename to newnonesuch;
 -- no such relation 
 alter table nonesuch rename to stud_emp;
 
--- system relation 
-alter table stud_emp rename to pg_stud_emp;
-
 -- conflict 
 alter table stud_emp rename to aggtest;
 
@@ -116,45 +113,18 @@ end;
 
 --
 -- DEFINE AGGREGATE
- 
--- left out finalfunc 
-create aggregate newavg1 (sfunc1 = int4pl,
-			  basetype = int4,
-			  stype1 = int4,
-			  sfunc2 = int4inc,
-			  stype2 = int4, 
-			  initcond1 = '0',
-			  initcond2 = '0');
-
--- sfunc return type disagreement 
-create aggregate newavg2 (sfunc1 = int4pl,
-			  basetype = int4,
-			  stype1 = int4,
-			  sfunc2 = int2inc,
-			  stype2 = int2,
-			  finalfunc = int4div,
-			  initcond1 = '0',
-			  initcond2 = '0');
 
 -- sfunc/finalfunc type disagreement 
-create aggregate newavg3 (sfunc1 = int4pl,
+create aggregate newavg2 (sfunc = int4pl,
 			  basetype = int4,
-			  stype1 = int4,
-			  sfunc2 = int4inc,
-			  stype2 = int4,
-			  finalfunc = int2div,
-			  initcond1 = '0',
-			  initcond2 = '0');
+			  stype = int4,
+			  finalfunc = int2um,
+			  initcond = '0');
 
 -- left out basetype
-create aggregate newcnt1 (sfunc2 = int4inc,
-			  stype2 = int4,
-			initcond2 = '0');
-
--- left out initcond2 (for sfunc2) 
-create aggregate newcnt1 (sfunc2 = int4inc,
-			  basetype = int4,
-			  stype2 = int4);
+create aggregate newcnt1 (sfunc = int4inc,
+			  stype = int4,
+			  initcond = '0');
 
 
 --
@@ -176,20 +146,20 @@ drop index nonesuch;
 -- missing aggregate name 
 drop aggregate;
 
--- bad aggregate name 
-drop aggregate 314159;
-
--- no such aggregate 
-drop aggregate nonesuch;
-
 -- missing aggregate type
 drop aggregate newcnt1;
 
+-- bad aggregate name 
+drop aggregate 314159 (int);
+
 -- bad aggregate type
-drop aggregate newcnt nonesuch;
+drop aggregate newcnt (nonesuch);
+
+-- no such aggregate 
+drop aggregate nonesuch (int4);
 
 -- no such aggregate for type
-drop aggregate newcnt float4;
+drop aggregate newcnt (float4);
 
 
 --
@@ -271,13 +241,13 @@ drop rule;
 drop rule 314159;
 
 -- no such rule 
-drop rule nonesuch;
+drop rule nonesuch on noplace;
 
 -- bad keyword 
 drop tuple rule nonesuch;
 
 -- no such rule 
-drop instance rule nonesuch;
+drop instance rule nonesuch on noplace;
 
 -- no such rule 
 drop rewrite rule nonesuch;
